==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/SynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessageSet;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InformalSynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InterfaceOperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.MSG_MSet;
import io.ciera.tool.sql.ooaofooa.message.OperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.BridgeMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InformalSynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InterfaceOperationMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.MSG_MSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.OperationMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class SynchronousMessageSetImpl extends InstanceSet<SynchronousMessageSet,SynchronousMessage> implements SynchronousMessageSet {

    // attributes
    @Override
    public void setResultTarget( String m_ResultTarget ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setResultTarget( m_ResultTarget );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setLabel( m_Label );
    }
    @Override
    public void setGuardCondition( String m_GuardCondition ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setGuardCondition( m_GuardCondition );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setReturnValue( String m_ReturnValue ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setReturnValue( m_ReturnValue );
    }
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setInformalName( m_InformalName );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setDescrip( m_Descrip );
    }
    @Override
    public void setSequenceNumb( String m_SequenceNumb ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setSequenceNumb( m_SequenceNumb );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setIsFormal( m_isFormal );
    }


    // selections
    @Override
    public MSG_MSet R1018_is_a_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) msg_mset.add( synchronousmessage.R1018_is_a_MSG_M() );
        return msg_mset;
    }
    @Override
    public BridgeMessageSet R1020_is_a_BridgeMessage() throws XtumlException {
        BridgeMessageSet bridgemessageset = new BridgeMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) bridgemessageset.add( synchronousmessage.R1020_is_a_BridgeMessage() );
        return bridgemessageset;
    }
    @Override
    public FunctionMessageSet R1020_is_a_FunctionMessage() throws XtumlException {
        FunctionMessageSet functionmessageset = new FunctionMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) functionmessageset.add( synchronousmessage.R1020_is_a_FunctionMessage() );
        return functionmessageset;
    }
    @Override
    public InformalSynchronousMessageSet R1020_is_a_InformalSynchronousMessage() throws XtumlException {
        InformalSynchronousMessageSet informalsynchronousmessageset = new InformalSynchronousMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) informalsynchronousmessageset.add( synchronousmessage.R1020_is_a_InformalSynchronousMessage() );
        return informalsynchronousmessageset;
    }
    @Override
    public InterfaceOperationMessageSet R1020_is_a_InterfaceOperationMessage() throws XtumlException {
        InterfaceOperationMessageSet interfaceoperationmessageset = new InterfaceOperationMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) interfaceoperationmessageset.add( synchronousmessage.R1020_is_a_InterfaceOperationMessage() );
        return interfaceoperationmessageset;
    }
    @Override
    public OperationMessageSet R1020_is_a_OperationMessage() throws XtumlException {
        OperationMessageSet operationmessageset = new OperationMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) operationmessageset.add( synchronousmessage.R1020_is_a_OperationMessage() );
        return operationmessageset;
    }


    @Override
    public SynchronousMessage nullElement() {
        return SynchronousMessageImpl.EMPTY_SYNCHRONOUSMESSAGE;
    }

    @Override
    public SynchronousMessageSet emptySet() {
      return new SynchronousMessageSetImpl();
    }

    @Override
    public SynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<SynchronousMessage> elements() {
        return Arrays.asList(toArray(new SynchronousMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/SynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessageSet;
import io.ciera.tool.sql.ooaofooa.message.FunctionMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InformalSynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.InterfaceOperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.MSG_MSet;
import io.ciera.tool.sql.ooaofooa.message.OperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.BridgeMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InformalSynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InterfaceOperationMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.MSG_MSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.OperationMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SynchronousMessageSetImpl extends InstanceSet<SynchronousMessageSet,SynchronousMessage> implements SynchronousMessageSet {

    public SynchronousMessageSetImpl() {
    }

    public SynchronousMessageSetImpl(Comparator<? super SynchronousMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setDescrip( m_Descrip );
    }
    @Override
    public void setReturnValue( String m_ReturnValue ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setReturnValue( m_ReturnValue );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setIsFormal( m_isFormal );
    }
    @Override
    public void setResultTarget( String m_ResultTarget ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setResultTarget( m_ResultTarget );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setInformalName( m_InformalName );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setLabel( m_Label );
    }
    @Override
    public void setSequenceNumb( String m_SequenceNumb ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setSequenceNumb( m_SequenceNumb );
    }
    @Override
    public void setGuardCondition( String m_GuardCondition ) throws XtumlException {
        for ( SynchronousMessage synchronousmessage : this ) synchronousmessage.setGuardCondition( m_GuardCondition );
    }


    // selections
    @Override
    public MSG_MSet R1018_is_a_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) msg_mset.add( synchronousmessage.R1018_is_a_MSG_M() );
        return msg_mset;
    }
    @Override
    public BridgeMessageSet R1020_is_a_BridgeMessage() throws XtumlException {
        BridgeMessageSet bridgemessageset = new BridgeMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) bridgemessageset.add( synchronousmessage.R1020_is_a_BridgeMessage() );
        return bridgemessageset;
    }
    @Override
    public FunctionMessageSet R1020_is_a_FunctionMessage() throws XtumlException {
        FunctionMessageSet functionmessageset = new FunctionMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) functionmessageset.add( synchronousmessage.R1020_is_a_FunctionMessage() );
        return functionmessageset;
    }
    @Override
    public InformalSynchronousMessageSet R1020_is_a_InformalSynchronousMessage() throws XtumlException {
        InformalSynchronousMessageSet informalsynchronousmessageset = new InformalSynchronousMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) informalsynchronousmessageset.add( synchronousmessage.R1020_is_a_InformalSynchronousMessage() );
        return informalsynchronousmessageset;
    }
    @Override
    public InterfaceOperationMessageSet R1020_is_a_InterfaceOperationMessage() throws XtumlException {
        InterfaceOperationMessageSet interfaceoperationmessageset = new InterfaceOperationMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) interfaceoperationmessageset.add( synchronousmessage.R1020_is_a_InterfaceOperationMessage() );
        return interfaceoperationmessageset;
    }
    @Override
    public OperationMessageSet R1020_is_a_OperationMessage() throws XtumlException {
        OperationMessageSet operationmessageset = new OperationMessageSetImpl();
        for ( SynchronousMessage synchronousmessage : this ) operationmessageset.add( synchronousmessage.R1020_is_a_OperationMessage() );
        return operationmessageset;
    }


    @Override
    public SynchronousMessage nullElement() {
        return SynchronousMessageImpl.EMPTY_SYNCHRONOUSMESSAGE;
    }

    @Override
    public SynchronousMessageSet emptySet() {
      return new SynchronousMessageSetImpl();
    }

    @Override
    public SynchronousMessageSet emptySet(Comparator<? super SynchronousMessage> comp) {
      return new SynchronousMessageSetImpl(comp);
    }

    @Override
    public SynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<SynchronousMessage> elements() {
        return Arrays.asList(toArray(new SynchronousMessage[0]));
    }

}
